@@ -31,10 +31,12 @@ DWIDGET_USE_NAMESPACE
 DdeGrandSearchDockPlugin::DdeGrandSearchDockPlugin(QObject *parent)
     : QObject(parent), m_searchWidget(nullptr)
 {
+    qCDebug(logDock) << "Grand Search dock plugin constructor called";
 }
 
 DdeGrandSearchDockPlugin::~DdeGrandSearchDockPlugin()
 {
+    qCDebug(logDock) << "Grand Search dock plugin destructor called";
 }
 
 const QString DdeGrandSearchDockPlugin::pluginName() const
@@ -49,11 +51,14 @@ const QString DdeGrandSearchDockPlugin::pluginDisplayName() const
 
 void DdeGrandSearchDockPlugin::init(PluginProxyInterface *proxyInter)
 {
+    qCDebug(logDock) << "Initializing Grand Search dock plugin";
+
     // 加载翻译
     QString appName = qApp->applicationName();
     qApp->setApplicationName(GrandSearchApp);
     qApp->loadTranslator();
     qApp->setApplicationName(appName);
+    qCDebug(logDock) << "Translation loaded for Grand Search dock plugin";
 
     m_proxyInter = proxyInter;
 
@@ -61,13 +66,18 @@ void DdeGrandSearchDockPlugin::init(PluginProxyInterface *proxyInter)
         m_searchWidget.reset(new GrandSearchWidget);
         connect(m_searchWidget.data(), &GrandSearchWidget::visibleChanged, this,
                 &DdeGrandSearchDockPlugin::onVisibleChanged);
+        qCDebug(logDock) << "Grand Search widget created and connected";
     }
-    if (m_tipsWidget.isNull())
+    if (m_tipsWidget.isNull()) {
         m_tipsWidget.reset(new TipsWidget);
+        qCDebug(logDock) << "Tips widget created";
+    }
 
 #ifdef USE_DOCK_2_0
-    if (m_quickWidget.isNull())
+    if (m_quickWidget.isNull()) {
         m_quickWidget.reset(new QuickPanel(pluginDisplayName()));
+        qCDebug(logDock) << "Quick panel widget created for dock 2.0";
+    }
 #endif
 
     // 如果插件没有被禁用则在初始化插件时才添加主控件到面板上
@@ -78,25 +88,36 @@ void DdeGrandSearchDockPlugin::init(PluginProxyInterface *proxyInter)
     if (QGSettings::isSchemaInstalled(SchemaId)) {
         m_gsettings.reset(new QGSettings(SchemaId, SchemaPath));
         connect(m_gsettings.data(), &QGSettings::changed, this, &DdeGrandSearchDockPlugin::onGsettingsChanged);
+        qCDebug(logDock) << "GSettings initialized for Grand Search dock plugin - Schema:" << SchemaId;
     } else {
         qCWarning(logDock) << "GSettings schema not found - Schema:" << SchemaId;
     }
 #endif
+
+    qCDebug(logDock) << "Grand Search dock plugin initialization completed";
 }
 
 QWidget *DdeGrandSearchDockPlugin::itemWidget(const QString &itemKey)
 {
-    if (itemKey == QUICK_ITEM_KEY)
-        return m_quickWidget.data();
-    else if (itemKey == GrandSearchPlugin)
-        return m_searchWidget.data();
+    qCDebug(logDock) << "Requesting item widget for key:" << itemKey;
 
+    if (itemKey == QUICK_ITEM_KEY) {
+        qCDebug(logDock) << "Returning quick panel widget";
+        return m_quickWidget.data();
+    } else if (itemKey == GrandSearchPlugin) {
+        qCDebug(logDock) << "Returning grand search widget";
+        return m_searchWidget.data();
+    }
+
+    qCWarning(logDock) << "Unknown item key requested:" << itemKey;
     return nullptr;
 }
 
 QWidget *DdeGrandSearchDockPlugin::itemTipsWidget(const QString &itemKey)
 {
     Q_UNUSED(itemKey);
+    qCDebug(logDock) << "Setting up tips widget for item:" << itemKey;
+
     // 设置/刷新 tips 中的信息
     m_tipsWidget->setText(tr("Grand Search"));
     return m_tipsWidget.data();
@@ -105,6 +126,7 @@ QWidget *DdeGrandSearchDockPlugin::itemTipsWidget(const QString &itemKey)
 bool DdeGrandSearchDockPlugin::pluginIsAllowDisable()
 {
     // 插件允许禁用
+    qCDebug(logDock) << "Grand Search plugin allows disable: true";
     return true;
 }
 
@@ -117,26 +139,35 @@ bool DdeGrandSearchDockPlugin::pluginIsDisable()
 
 void DdeGrandSearchDockPlugin::pluginStateSwitched()
 {
+    qCDebug(logDock) << "Grand Search plugin state switching triggered";
+
     // 获取当前禁用状态的反值作为新的状态值
     const bool disabledNew = !pluginIsDisable();
+    qCDebug(logDock) << "Switching Grand Search plugin state - New disabled state:" << disabledNew;
+
     // 存储新的状态值
     m_proxyInter->saveValue(this, "disabled", disabledNew);
 
     // 根据新的禁用状态值处理主控件的加载和卸载
     if (disabledNew) {
         m_proxyInter->itemRemoved(this, pluginName());
+        qCDebug(logDock) << "Grand Search plugin item removed from dock - Plugin disabled";
     } else {
         m_proxyInter->itemAdded(this, pluginName());
+        qCDebug(logDock) << "Grand Search plugin item added to dock - Plugin enabled";
     }
 }
 
 const QString DdeGrandSearchDockPlugin::itemCommand(const QString &itemKey)
 {
+    qCDebug(logDock) << "Executing item command for key:" << itemKey;
+
     if (GrandSearchPlugin == itemKey || itemKey == QUICK_ITEM_KEY) {
         m_proxyInter->requestSetAppletVisible(this, pluginName(), false);
         return m_searchWidget->itemCommand(itemKey);
     }
 
+    qCWarning(logDock) << "Unknown item command requested for key:" << itemKey;
     return QString();
 }
 
@@ -150,11 +181,15 @@ void DdeGrandSearchDockPlugin::setSortKey(const QString &itemKey, const int orde
 {
     const QString key = QString("pos_%1_%2").arg(itemKey).arg(Dock::Efficient);
     m_proxyInter->saveValue(this, key, order);
+    qCDebug(logDock) << "Setting sort key for item:" << itemKey << "Key:" << key << "Order:" << order;
 }
 
 const QString DdeGrandSearchDockPlugin::itemContextMenu(const QString &itemKey)
 {
+    qCDebug(logDock) << "Generating context menu for item:" << itemKey;
+
     if (itemKey != GrandSearchPlugin && itemKey != QUICK_ITEM_KEY) {
+        qCWarning(logDock) << "Context menu requested for unknown item:" << itemKey;
         return QString();
     }
 
@@ -178,9 +213,12 @@ const QString DdeGrandSearchDockPlugin::itemContextMenu(const QString &itemKey)
 void DdeGrandSearchDockPlugin::invokedMenuItem(const QString &itemKey, const QString &menuId, const bool checked)
 {
     Q_UNUSED(checked)
+    qCDebug(logDock) << "Menu item invoked - Item:" << itemKey << "Menu:" << menuId << "Checked:" << checked;
 
-    if (itemKey != GrandSearchPlugin && itemKey != QUICK_ITEM_KEY)
+    if (itemKey != GrandSearchPlugin && itemKey != QUICK_ITEM_KEY) {
+        qCWarning(logDock) << "Menu invoked for unknown item:" << itemKey;
         return;
+    }
 
     if (menuId == MenuOpenSetting) {
         QProcess::startDetached("dbus-send", QStringList() << "--print-reply" << "--dest=com.deepin.dde.GrandSearchSetting" << "/com/deepin/dde/GrandSearchSetting" << "com.deepin.dde.GrandSearchSetting.Show");
@@ -203,6 +241,8 @@ void DdeGrandSearchDockPlugin::onGsettingsChanged(const QString &key)
 #endif
 void DdeGrandSearchDockPlugin::onVisibleChanged(bool visible)
 {
+    qCDebug(logDock) << "Grand Search visibility changed:" << visible;
+
 #ifdef USE_DOCK_2_0
     if (!m_messageCallback) {
         qCWarning(logDock) << "Message callback function not initialized";
@@ -215,5 +255,6 @@ void DdeGrandSearchDockPlugin::onVisibleChanged(bool visible)
     QJsonDocument doc;
     doc.setObject(obj);
     m_messageCallback(this, doc.toJson());
+    qCDebug(logDock) << "Dock 2.0 message callback executed for visibility change";
 #endif
 }
