@@ -13,6 +13,9 @@
 #include <QBuffer>
 #include <QGuiApplication>
 #include <QProcess>
+#include <QLoggingCategory>
+
+Q_LOGGING_CATEGORY(logShell, "org.deepin.dde.dock.shell.grandsearch")
 
 DGUI_USE_NAMESPACE
 namespace dock
@@ -31,20 +34,25 @@ SearchItem::SearchItem(QObject *parent)
     , m_visible(true)
     , m_grandSearchVisible(false)
 {
+    qCDebug(logShell) << "Grand Search shell plugin initialized";
 }
 
 void SearchItem::toggleGrandSearch()
 {
+    qCDebug(logShell) << "Toggling Grand Search visibility via shell plugin";
     searchDbus().method("SetVisible").arg(true).call();
 }
 
 void SearchItem::toggleGrandSearchConfig()
 {
+    qCDebug(logShell) << "Opening Grand Search configuration via shell plugin";
     QProcess::startDetached("dde-grand-search", QStringList() << "--setting");
 }
 
 void SearchItem::setVisible(bool visible)
 {
+    qCDebug(logShell) << "Setting shell plugin visibility - From:" << m_visible << "To:" << visible;
+
     if (m_visible != visible) {
         m_visible = visible;
 
@@ -54,6 +62,8 @@ void SearchItem::setVisible(bool visible)
 
 void SearchItem::onGrandSearchVisibleChanged(bool visible)
 {
+    qCDebug(logShell) << "Grand Search visibility change notification received - From:" << m_grandSearchVisible << "To:" << visible;
+
     if (m_grandSearchVisible != visible) {
         m_grandSearchVisible = visible;
 
