@@ -25,26 +25,28 @@
 
 #include <QHBoxLayout>
 #include <QVBoxLayout>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logGrandSearch)
 
 using namespace GrandSearch;
 DWIDGET_USE_NAMESPACE
 
-#define ListItemHeight            36       // 列表行高
-#define GroupLabelHeight          28       // 组标签高度
-#define MoreBtnMaxHeight          25       // 查看更多按钮最大高度
-#define LayoutMagrinSize          10       // 布局边距
-#define SpacerWidth               40       // 弹簧宽度
-#define SpacerHeight              20       // 弹簧高度
+#define ListItemHeight 36   // 列表行高
+#define GroupLabelHeight 28   // 组标签高度
+#define MoreBtnMaxHeight 25   // 查看更多按钮最大高度
+#define LayoutMagrinSize 10   // 布局边距
+#define SpacerWidth 40   // 弹簧宽度
+#define SpacerHeight 20   // 弹簧高度
 
 GroupWidgetPrivate::GroupWidgetPrivate(GroupWidget *parent)
     : q_p(parent)
 {
-
 }
 
 GroupWidget::GroupWidget(QWidget *parent)
-    : DWidget(parent)
-    , d_p(new GroupWidgetPrivate(this))
+    : DWidget(parent),
+      d_p(new GroupWidgetPrivate(this))
 {
     m_firstFiveItems.clear();
     m_restShowItems.clear();
@@ -57,7 +59,6 @@ GroupWidget::GroupWidget(QWidget *parent)
 
 GroupWidget::~GroupWidget()
 {
-
 }
 
 void GroupWidget::setGroupName(const QString &groupName)
@@ -70,7 +71,7 @@ void GroupWidget::setGroupName(const QString &groupName)
     AC_SET_ACCESSIBLE_NAME(m_listView, groupName);
 }
 
-void GroupWidget::appendMatchedItems(const MatchedItems &newItems, const QString& searchGroupName)
+void GroupWidget::appendMatchedItems(const MatchedItems &newItems, const QString &searchGroupName)
 {
     Q_UNUSED(searchGroupName)
 
@@ -83,8 +84,8 @@ void GroupWidget::appendMatchedItems(const MatchedItems &newItems, const QString
         if (0 == m_listView->rowCount()) {
             const MatchedItem &item = newItems.first();
             if (!item.extra.isNull()
-                    && item.extra.type() == QVariant::Hash
-                    && item.extra.toHash().keys().contains(GRANDSEARCH_PROPERTY_ITEM_WEIGHT)) {
+                && item.extra.type() == QVariant::Hash
+                && item.extra.toHash().keys().contains(GRANDSEARCH_PROPERTY_ITEM_WEIGHT)) {
                 // 已经排序过，直接显示
                 m_cacheWeightItems << newItems;
                 updateShowItems(m_cacheWeightItems);
@@ -99,7 +100,7 @@ void GroupWidget::appendMatchedItems(const MatchedItems &newItems, const QString
         updateShowItems(m_cacheItems);
     } else {
         // 结果列表已展开，已经显示的数据保持不变，仅对新增数据排序，然后追加到列表末尾
-        MatchedItems& tempNewItems = const_cast<MatchedItems&>(newItems);
+        MatchedItems &tempNewItems = const_cast<MatchedItems &>(newItems);
         Utils::sortByWeight(tempNewItems);
         m_listView->addRows(tempNewItems);
     }
@@ -116,7 +117,7 @@ bool GroupWidget::isHorLineVisilbe()
 {
     Q_ASSERT(m_line);
 
-    return  m_line->isVisible();
+    return m_line->isVisible();
 }
 
 GrandSearchListView *GroupWidget::getListView()
@@ -223,10 +224,10 @@ QString GroupWidget::groupName() const
 void GroupWidget::setIcon(const QIcon &icon)
 {
     if (icon.isNull()) {
-       m_groupIcon->hide();
+        m_groupIcon->hide();
     } else {
-       m_groupIcon->setPixmap(icon.pixmap(QSize(18, 18)));
-       m_groupIcon->show();
+        m_groupIcon->setPixmap(icon.pixmap(QSize(18, 18)));
+        m_groupIcon->show();
     }
 }
 
@@ -253,7 +254,10 @@ void GroupWidget::showLabel(bool bShow)
         bool isUpdateIdx = IntelligentRetrievalWidget::isUpdateIndex();
         // 有无安装大模型
         bool hasModel = IntelligentRetrievalWidget::isQueryLangSupported();
-        qDebug() << QString("idxDir(%1) hasIdx(%2) isUpdateIdx(%3) hasModel(%4)").arg(idxDir).arg(hasIdx).arg(isUpdateIdx).arg(hasModel);
+        qCDebug(logGrandSearch) << "AI inference state - Index directory:" << idxDir
+                                << "Has index:" << hasIdx
+                                << "Auto-update enabled:" << isUpdateIdx
+                                << "Model available:" << hasModel;
 
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         const QColor &color = DPaletteHelper::instance()->palette(m_resultLabel).color(DPalette::Normal, DPalette::Highlight);
@@ -263,16 +267,16 @@ void GroupWidget::showLabel(bool bShow)
         if (!hasIdx && !isUpdateIdx && !hasModel) {
             // 请先前往搜索配置安装UOS AI大模型，并开启自动更新索引 Please go to Search configration to install the ULLM, and turn on Automatic index update.
             m_resultLabel->setText(tr("Please go to %1 to install the ULLM, and %2 Automatic index update.")
-                                   .arg(QString("<a href=\"config\" style=\"color:%1; text-decoration: none;\">%2</a>").arg(color.name()).arg(tr("Search configration")))
-                                   .arg(QString("<a href=\"update index\" style=\"color:%1; text-decoration: none;\">%2</a>").arg(color.name()).arg(tr("turn on"))));
+                                           .arg(QString("<a href=\"config\" style=\"color:%1; text-decoration: none;\">%2</a>").arg(color.name()).arg(tr("Search configration")))
+                                           .arg(QString("<a href=\"update index\" style=\"color:%1; text-decoration: none;\">%2</a>").arg(color.name()).arg(tr("turn on"))));
         } else if (!hasIdx && !isUpdateIdx) {
             // 请先开启自动更新索引 Please turn on Automatic index update.
             m_resultLabel->setText(tr("Please %1 Automatic index update.")
-                                   .arg(QString("<a href=\"update index\" style=\"color:%1; text-decoration: none;\">%2</a>").arg(color.name()).arg(tr("turn on"))));
+                                           .arg(QString("<a href=\"update index\" style=\"color:%1; text-decoration: none;\">%2</a>").arg(color.name()).arg(tr("turn on"))));
         } else if (!hasModel) {
             // 请先前往搜索配置安装UOS AI大模型 Please go to Search configration to install the UOS AI large model.
             m_resultLabel->setText(tr("Please go to %1 to install the ULLM.")
-                                   .arg(QString("<a href=\"config\" style=\"color:%1; text-decoration: none;\">%2</a>").arg(color.name()).arg(tr("Search configration"))));
+                                           .arg(QString("<a href=\"config\" style=\"color:%1; text-decoration: none;\">%2</a>").arg(color.name()).arg(tr("Search configration"))));
         } else {
             m_resultLabel->setText(tr("No search results"));
         }
@@ -281,18 +285,8 @@ void GroupWidget::showLabel(bool bShow)
 
 QString GroupWidget::convertDisplayName(const QString &searchGroupName)
 {
-    static const QHash<QString, QString> groupDisplayName{
-        {GRANDSEARCH_GROUP_BEST, GroupName_Best}
-        , {GRANDSEARCH_GROUP_APP, GroupName_App}
-        , {GRANDSEARCH_GROUP_SETTING, GroupName_Setting}
-        , {GRANDSEARCH_GROUP_FILE_VIDEO, GroupName_Video}
-        , {GRANDSEARCH_GROUP_FILE_AUDIO, GroupName_Audio}
-        , {GRANDSEARCH_GROUP_FILE_PICTURE, GroupName_Picture}
-        , {GRANDSEARCH_GROUP_FILE_DOCUMNET, GroupName_Document}
-        , {GRANDSEARCH_GROUP_FOLDER, GroupName_Folder}
-        , {GRANDSEARCH_GROUP_FILE, GroupName_File}
-        , {GRANDSEARCH_GROUP_WEB, GroupName_Web}
-        , {GRANDSEARCH_GROUP_FILE_INFERENCE, GroupName_Inference}
+    static const QHash<QString, QString> groupDisplayName {
+        { GRANDSEARCH_GROUP_BEST, GroupName_Best }, { GRANDSEARCH_GROUP_APP, GroupName_App }, { GRANDSEARCH_GROUP_SETTING, GroupName_Setting }, { GRANDSEARCH_GROUP_FILE_VIDEO, GroupName_Video }, { GRANDSEARCH_GROUP_FILE_AUDIO, GroupName_Audio }, { GRANDSEARCH_GROUP_FILE_PICTURE, GroupName_Picture }, { GRANDSEARCH_GROUP_FILE_DOCUMNET, GroupName_Document }, { GRANDSEARCH_GROUP_FOLDER, GroupName_Folder }, { GRANDSEARCH_GROUP_FILE, GroupName_File }, { GRANDSEARCH_GROUP_WEB, GroupName_Web }, { GRANDSEARCH_GROUP_FILE_INFERENCE, GroupName_Inference }
     };
 
     return groupDisplayName.value(searchGroupName, searchGroupName);
@@ -301,9 +295,9 @@ QString GroupWidget::convertDisplayName(const QString &searchGroupName)
 void GroupWidget::initUi()
 {
     // 获取设置当前窗口文本颜色
-    QColor groupTextColor = QColor(0, 0, 0, static_cast<int>(255*0.6));
+    QColor groupTextColor = QColor(0, 0, 0, static_cast<int>(255 * 0.6));
     if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType)
-        groupTextColor = QColor(255, 255, 255, static_cast<int>(255*0.6));
+        groupTextColor = QColor(255, 255, 255, static_cast<int>(255 * 0.6));
     QPalette labelPalette;
     labelPalette.setColor(QPalette::WindowText, groupTextColor);
 
@@ -322,7 +316,7 @@ void GroupWidget::initUi()
 
     // 组名图标
     m_groupIcon = new DLabel("", this);
-    m_groupIcon->setFixedSize(QSize(23, GroupLabelHeight)); // 18px of icon and 5px space
+    m_groupIcon->setFixedSize(QSize(23, GroupLabelHeight));   // 18px of icon and 5px space
     m_groupIcon->setAlignment(Qt::AlignVCenter | Qt::AlignLeft);
     m_groupLabel->setContentsMargins(0, 5, 5, 5);
     m_groupIcon->hide();
@@ -345,7 +339,7 @@ void GroupWidget::initUi()
 
     QWidget *spinnerContainer = new QWidget(this);
     {
-        spinnerContainer->setFixedSize(38, 18); //20px space on right.
+        spinnerContainer->setFixedSize(38, 18);   // 20px space on right.
         m_spinner = new DSpinner(spinnerContainer);
         m_spinner->setAttribute(Qt::WA_TransparentForMouseEvents);
         m_spinner->setFocusPolicy(Qt::NoFocus);
@@ -360,7 +354,7 @@ void GroupWidget::initUi()
     m_hTitelLayout->setSpacing(0);
     m_hTitelLayout->addWidget(m_groupIcon);
     m_hTitelLayout->addWidget(m_groupLabel);
-    m_hTitelLayout->addSpacerItem(new QSpacerItem(SpacerWidth,SpacerHeight,QSizePolicy::Expanding, QSizePolicy::Minimum));
+    m_hTitelLayout->addSpacerItem(new QSpacerItem(SpacerWidth, SpacerHeight, QSizePolicy::Expanding, QSizePolicy::Minimum));
     m_hTitelLayout->addWidget(m_viewMoreButton);
     m_hTitelLayout->addWidget(spinnerContainer);
 
@@ -373,8 +367,7 @@ void GroupWidget::initUi()
     DFontSizeManager::instance()->bind(m_resultLabel, DFontSizeManager::T8, QFont::Normal);
     // color
     {
-        QColor colorText = DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType ?
-                    Qt::white : Qt::black;
+        QColor colorText = DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType ? Qt::white : Qt::black;
         colorText.setAlphaF(0.5);
         auto pal = m_resultLabel->palette();
         pal.setColor(m_resultLabel->foregroundRole(), colorText);
@@ -464,9 +457,9 @@ void GroupWidget::onMoreBtnClicked()
     m_bListExpanded = true;
 }
 
-void GroupWidget::onOpenConfig(const QString& link)
+void GroupWidget::onOpenConfig(const QString &link)
 {
-    const QStringList args = {"-s", "--position", "aiconfig"};
+    const QStringList args = { "-s", "--position", "aiconfig" };
     if (link == "update index") {
         IntelligentRetrievalWidget::setAutoIndex(true);
         QProcess::startDetached("dde-grand-search", args);
