@@ -8,7 +8,11 @@ using namespace GrandSearch;
 QSize LinkButton::sizeHint() const {
     QSize size;
     QFontMetrics fontMetrics(this->font());
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     size.setWidth(fontMetrics.width(this->text()));
+#else
+    size.setWidth(fontMetrics.horizontalAdvance(this->text()));
+#endif
     size.setHeight(fontMetrics.height());
     return size;
 }
