@@ -44,29 +44,36 @@ VideoPreviewPlugin::VideoPreviewPlugin(QObject *parent)
     : QObject(parent)
     , PreviewPlugin()
 {
-
+    qCDebug(logVideoPreview) << "VideoPreviewPlugin created";
 }
 
 VideoPreviewPlugin::~VideoPreviewPlugin()
 {
+    qCDebug(logVideoPreview) << "VideoPreviewPlugin destroyed";
     stopPreview();
     delete m_view;
 }
 
 void VideoPreviewPlugin::init(QObject *proxyInter)
 {
+    qCDebug(logVideoPreview) << "Initializing VideoPreviewPlugin";
     m_proxy = proxyInter;
     if (!m_view) {
         m_view = new VideoView();
         m_view->initUI();
+        qCDebug(logVideoPreview) << "VideoView created and initialized";
     }
 }
 #define PREVIEW_ASYNC_DECODE
 bool VideoPreviewPlugin::previewItem(const ItemInfo &item)
 {
     const QString path = item.value(PREVIEW_ITEMINFO_ITEM);
-    if (path.isEmpty())
+    if (path.isEmpty()) {
+        qCWarning(logVideoPreview) << "Video file path is empty - Cannot preview";
         return false;
+    }
+
+    qCDebug(logVideoPreview) << "Previewing video file - Path:" << path;
 
     //开启线程解析
 #ifdef PREVIEW_ASYNC_DECODE
@@ -164,6 +171,7 @@ bool VideoPreviewPlugin::previewItem(const ItemInfo &item)
     future.waitForFinished();
     updateInfo(future.result(), false);
 #endif
+    qCDebug(logVideoPreview) << "Video preview setup completed - Path:" << path;
     return true;
 }
 
@@ -179,6 +187,7 @@ QWidget *VideoPreviewPlugin::contentWidget() const
 
 bool VideoPreviewPlugin::stopPreview()
 {
+    qCDebug(logVideoPreview) << "Stopping video preview";
     if (!m_decode.isNull())
         m_decode->decoding = false;
     return true;
